import warnings


def grid_to_triple(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.grid_to_triple``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.grid_to_triple``.")

    return None


def linint1(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.linint1``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.linint1``.")

    return None


def linint2(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.linint2``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.linint2``.")

    return None


def linint2pts(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.linint2pts``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.linint2pts``.")

    return None


def moc_globe_atl(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.moc_globe_atl``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.moc_globe_atl``.")

    return None


def rcm2points(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.rcm2points``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.rcm2points``.")

    return None


def rcm2rgrid(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.rcm2rgrid``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.rcm2rgrid``.")

    return None


def rgrid2rcm(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.rgrid2rcm``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.rgrid2rcm``.")

    return None


def triple_to_grid(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.triple_to_grid``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.triple_to_grid``.")

    return None
